class for line objects

Objects from the Class

Objects can be created by calls to the function Line.

Slots

coords:

Object of class "matrix", containing the line coordinates

Methods

There are methods for bbox, coordinates, coordnames, and spsample.

There is also a lines method to add lines to a plot.

Author

Roger Bivand, Edzer Pebesma

See also

The generator function Line, and the related classes "Lines" and "SpatialLines".