"Line"Line-class.Rdclass for line objects
Objects can be created by calls to the function Line.
coords:Object of class "matrix", containing the
line coordinates
There are methods for
bbox,
coordinates,
coordnames, and
spsample.
There is also a lines method to add lines to a plot.
The generator function Line, and the related classes
"Lines" and "SpatialLines".