powered by
"Line"
class for line objects
Objects can be created by calls to the function Line.
Line
coords
Object of class "matrix", containing the line coordinates
"matrix"
There are methods for bbox, coordinates, coordnames, and spsample.
bbox
coordinates
coordnames
spsample
There is also a lines method to add lines to a plot.
lines
Roger Bivand, Edzer Pebesma
The generator function Line, and the related classes "Lines" and "SpatialLines".
"Lines"
"SpatialLines"