class for sets of line objects

Objects from the Class

Objects can be created by calls to the function Lines.

Slots

Lines:

Object of class "list", containing elements of class "Line"

ID:

"character" vector of length one, with unique identifier string

Methods

There are methods for bbox, coordinates, coordnames, and spsample.

There is also a lines method to add lines to a plot.

Author

Roger Bivand, Edzer Pebesma

See also

The generator function Lines, and the related classes "Line" and "SpatialLines".