| Lines-class | R Documentation |
"Lines"class for sets of line objects
Objects can be created by calls to the function Lines.
Lines:Object of class "list", containing elements
of class "Line"
ID:"character" vector of length one, with unique identifier string
There are methods for
bbox,
coordinates,
coordnames, and
spsample.
There is also a lines method to add lines to a plot.
Roger Bivand, Edzer Pebesma
The generator function Lines, and the related classes
"Line" and "SpatialLines".
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.