powered by
"Lines"
class for sets of line objects
Objects can be created by calls to the function Lines.
Lines
Object of class "list", containing elements of class "Line"
"list"
"Line"
ID
"character" vector of length one, with unique identifier string
"character"
There are methods for bbox, coordinates, coordnames, and spsample.
bbox
coordinates
coordnames
spsample
There is also a lines method to add lines to a plot.
lines
Roger Bivand, Edzer Pebesma
The generator function Lines, and the related classes "Line" and "SpatialLines".
"SpatialLines"